==> jc-1.4.0.tar.gz: gnu/xml/pipeline/ValidationConsumer__241.h <==
// final class gnu.xml.pipeline.ValidationConsumer$1

// class file dependencies
// @dep_class d6ce6c15d02eb286 gnu_xml_pipeline_ValidationConsumer__241
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__241_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__241_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__241$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__241$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$refs	_jc_gnu_xml_pipeline_ValidationConsumer__241$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__241$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object	_jc_gnu_xml_pipeline_ValidationConsumer__241$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__241$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__241$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__241$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__241$method$_init$30b813adb4cc3600(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer$object *);

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vmethods {
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__241$vmethods	gnu_xml_pipeline_ValidationConsumer__241;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_refs {
	struct _jc_gnu_xml_pipeline_ValidationConsumer$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_refs	gnu_xml_pipeline_ValidationConsumer__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__241;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__241$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__241$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__241$vtype _jc_gnu_xml_pipeline_ValidationConsumer__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__241$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__241_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/ValidationConsumer__241.h <==
// final class gnu.xml.pipeline.ValidationConsumer$1

// class file dependencies
// @dep_class d6ce6c15d02eb286 gnu_xml_pipeline_ValidationConsumer__241
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_pipeline_ValidationConsumer__241_H_
#define _JC_gnu_xml_pipeline_ValidationConsumer__241_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_ValidationConsumer$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_refs	_jc_gnu_xml_pipeline_ValidationConsumer__241$sub_refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__241$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$refs	_jc_gnu_xml_pipeline_ValidationConsumer__241$refs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$nonrefs	_jc_gnu_xml_pipeline_ValidationConsumer__241$nonrefs;
typedef struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object	_jc_gnu_xml_pipeline_ValidationConsumer__241$object;

typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vmethods	_jc_gnu_xml_pipeline_ValidationConsumer__241$vmethods;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vtable	_jc_gnu_xml_pipeline_ValidationConsumer__241$vtable;
typedef const struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vtype	_jc_gnu_xml_pipeline_ValidationConsumer__241$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_ValidationConsumer__241$method$_init$30b813adb4cc3600(_jc_env *, struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object *, struct _jc_gnu_xml_pipeline_ValidationConsumer$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vmethods {
};

// Vtable
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_ValidationConsumer__241$vmethods	gnu_xml_pipeline_ValidationConsumer__241;
};

// Vtype
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_ValidationConsumer__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_refs {
	struct _jc_gnu_xml_pipeline_ValidationConsumer$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$refs {
    _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_refs	gnu_xml_pipeline_ValidationConsumer__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_ValidationConsumer__241$sub_nonrefs	gnu_xml_pipeline_ValidationConsumer__241;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_ValidationConsumer__241$object {
	_jc_gnu_xml_pipeline_ValidationConsumer__241$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_ValidationConsumer__241$vtype	*vtype;
	_jc_gnu_xml_pipeline_ValidationConsumer__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_ValidationConsumer__241$vtype _jc_gnu_xml_pipeline_ValidationConsumer__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_ValidationConsumer__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_ValidationConsumer__241$class_object;

#endif	/* _JC_gnu_xml_pipeline_ValidationConsumer__241_H_ */
